"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _constants = require("./constants");

const init = async ({
  promise,
  createQuery,
  transformEvents
}) => {
  if (promise[_constants.symbol].phase < _constants.Phases.RESOLVER) {
    throw new TypeError();
  }

  let queryExecutor = null;

  try {
    queryExecutor = createQuery({
      doUpdateRequest: Promise.resolve.bind(Promise),
      eventStore: null,
      viewModels: [],
      readModels: [{
        name: promise[_constants.symbol].name,
        projection: promise[_constants.symbol].projection,
        resolvers: promise[_constants.symbol].resolvers,
        connectorName: 'ADAPTER_NAME'
      }],
      readModelConnectors: {
        ADAPTER_NAME: promise[_constants.symbol].adapter
      },
      snapshotAdapter: null
    });
    let updateResult = null;

    try {
      updateResult = await queryExecutor.updateByEvents(promise[_constants.symbol].name, transformEvents(promise[_constants.symbol].events));
    } catch (error) {
      updateResult = error;
    }

    if (updateResult != null && updateResult.lastError != null) {
      throw updateResult.lastError;
    }

    const result = await queryExecutor.read({
      modelName: promise[_constants.symbol].name,
      resolverName: promise[_constants.symbol].resolverName,
      resolverArgs: promise[_constants.symbol].resolverArgs,
      jwtToken: promise[_constants.symbol].jwtToken
    });

    promise[_constants.symbol].resolve(result);
  } catch (error) {
    promise[_constants.symbol].reject(error);
  } finally {
    await queryExecutor.dispose();
  }
};

var _default = init;
exports.default = _default;
//# sourceMappingURL=init-read-model.js.map